@@ -55,7 +55,7 @@ void init_parse_options(int argc, char **argv)
 	opt.display = 1;
 	opt.aspect = 1;
 	opt.slideshow_delay = 0.0;
-	opt.magick_timeout = -1;
+	opt.conversion_timeout = -1;
 	opt.thumb_w = 60;
 	opt.thumb_h = 60;
 	opt.thumb_redraw = 10;
@@ -415,6 +415,8 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"insecure"      , 0, 0, 240},
 		{"no-recursive"  , 0, 0, 241},
 		{"cache-size"    , 1, 0, 243},
+		{"on-last-slide" , 1, 0, 244},
+		{"conversion-timeout" , 1, 0, 245},
 		{"version-sort"  , 0, 0, 246},
 		{"offset"        , 1, 0, 247},
 		{0, 0, 0, 0}
@@ -693,7 +695,8 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			opt.index_info = estrdup(optarg);
 			break;
 		case 208:
-			opt.magick_timeout = atoi(optarg);
+			weprintf("--magick-timeout is deprecated, please use --conversion-timeout instead");
+			opt.conversion_timeout = atoi(optarg);
 			break;
 		case 209:
 			opt.actions[1] = estrdup(optarg);
@@ -740,7 +743,8 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			break;
 #endif
 		case 224:
-			opt.cycle_once = 1;
+			weprintf("--cycle-once is deprecated, please use --on-last-slide=quit instead");
+			opt.on_last_slide = ON_LAST_SLIDE_QUIT;
 			break;
 		case 225:
 			opt.xinerama = 0;
@@ -783,6 +787,21 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			if (opt.cache_size > 2048)
 				opt.cache_size = 2048;
 			break;
+		case 244:
+			if (!strcmp(optarg, "quit")) {
+				opt.on_last_slide = ON_LAST_SLIDE_QUIT;
+			} else if (!strcmp(optarg, "hold")) {
+				opt.on_last_slide = ON_LAST_SLIDE_HOLD;
+			} else if (!strcmp(optarg, "resume")) {
+				opt.on_last_slide = ON_LAST_SLIDE_RESUME;
+			} else {
+				weprintf("Unrecognized on-last-slide action \"%s\"."
+						"Supported actions: hold, resume, quit\n", optarg);
+			}
+			break;
+		case 245:
+			opt.conversion_timeout = atoi(optarg);
+			break;
 		case 246:
 			opt.version_sort = 1;
 			break;
